<?php
$a = str_repeat("/", 9000000);
var_dump(iconv_set_encoding("input_encoding", $a));
var_dump(iconv_set_encoding("output_encoding", $a));
var_dump(iconv_set_encoding("internal_encoding", $a));
?>
