<?php
/* Prototype  : proto int eregi(string pattern, string string [, array registers])
 * Description: Regular expression match 
 * Source code: ext/standard/reg.c
 * Alias to functions: 
 */

var_dump(eregi('l{2}', 'hello', str_repeat('x',1)));
echo "Done";
?>
