<?php
$a = array(1,2);
$aa1 =  new ArrayObject($a);
$a['p1'] = 'new element added to a before clone';

$aa2 = clone $aa1;

$a['p2'] = 'new element added to a after clone';
$aa1['new.aa1'] = 'new element added to aa1';
$aa2['new.aa2'] = 'new element added to aa2';
var_dump($a, $aa1, $aa2);
?>
